package java.net;

import java.util.Formatter;
import java.util.Locale;
import sun.net.util.IPAddressUtil;

class HostPortrange
{
    String hostname;
    String scheme;
    int[] portrange;
    boolean wildcard;
    boolean literal;
    boolean ipv6;
    boolean ipv4;
    static final int PORT_MIN = 0;
    static final int PORT_MAX = 65535;
    static final int CASE_DIFF = -32;
    static final int[] HTTP_PORT;
    static final int[] HTTPS_PORT;
    static final int[] NO_PORT;
    
    boolean equals(HostPortrange hostPortrange) {
        return this.hostname.equals(hostPortrange.hostname) && this.portrange[0] == hostPortrange.portrange[0] && this.portrange[1] == hostPortrange.portrange[1] && this.wildcard == hostPortrange.wildcard && this.literal == hostPortrange.literal;
    }
    
    @Override
    public int hashCode() {
        return this.hostname.hashCode() + this.portrange[0] + this.portrange[1];
    }
    
    HostPortrange(String scheme, String str) {
        String str2 = null;
        this.scheme = scheme;
        if (str.charAt(0) == '[') {
            boolean b2 = true;
            this.literal = b2;
            this.ipv6 = b2;
            int index2 = str.indexOf(93);
            if (index2 != -1) {
                String substring = str.substring(1, index2);
                int index3 = str.indexOf(58, index2 + 1);
                if (index3 != -1 && str.length() > index3) {
                    str2 = str.substring(index3 + 1);
                }
                byte[] textToNumericFormatV5 = IPAddressUtil.textToNumericFormatV6(substring);
                if (textToNumericFormatV5 == null) {
                    throw new IllegalArgumentException("illegal IPv6 address");
                }
                StringBuilder a2 = new StringBuilder();
                new Formatter(a2, Locale.US).format("%02x%02x:%02x%02x:%02x%02x:%02x%02x:%02x%02x:%02x%02x:%02x%02x:%02x%02x", new Object[] { Byte.valueOf(textToNumericFormatV5[0]), Byte.valueOf(textToNumericFormatV5[1]), Byte.valueOf(textToNumericFormatV5[2]), Byte.valueOf(textToNumericFormatV5[3]), Byte.valueOf(textToNumericFormatV5[4]), Byte.valueOf(textToNumericFormatV5[5]), Byte.valueOf(textToNumericFormatV5[6]), Byte.valueOf(textToNumericFormatV5[7]), Byte.valueOf(textToNumericFormatV5[8]), Byte.valueOf(textToNumericFormatV5[9]), Byte.valueOf(textToNumericFormatV5[10]), Byte.valueOf(textToNumericFormatV5[11]), Byte.valueOf(textToNumericFormatV5[12]), Byte.valueOf(textToNumericFormatV5[13]), Byte.valueOf(textToNumericFormatV5[14]), Byte.valueOf(textToNumericFormatV5[15]) });
                this.hostname = a2.toString();
            }
            else {
                throw new IllegalArgumentException("invalid IPv6 address: " + str);
            }
        }
        else {
            int index = str.indexOf(58);
            String s;
            if (index != -1 && str.length() > index) {
                s = str.substring(0, index);
                str2 = str.substring(index + 1);
            }
            else {
                s = ((index == -1) ? str : str.substring(0, index));
            }
            if (s.lastIndexOf(42) > 0) {
                throw new IllegalArgumentException("invalid host wildcard specification");
            }
            if (s.startsWith("*")) {
                this.wildcard = true;
                if (s.equals("*")) {
                    s = "";
                }
                else if (s.startsWith("*.")) {
                    s = toLowerCase(s.substring(1));
                }
                else {
                    throw new IllegalArgumentException("invalid host wildcard specification");
                }
            }
            else {
                int lastIndex = s.lastIndexOf(46);
                if (lastIndex != -1 && s.length() > 1) {
                    boolean n = true;
                    int i = lastIndex + 1;
                    while (i < s.length()) {
                        int char1 = s.charAt(i);
                        if (char1 < '0' || char1 > '9') {
                            n = false;
                            break;
                        }
                        ++i;
                    }
                    boolean b = n;
                    this.literal = b;
                    this.ipv4 = b;
                    if (!(n == 0)) {
                        byte[] textToNumericFormatV4 = IPAddressUtil.textToNumericFormatV4(s);
                        if (textToNumericFormatV4 == null) {
                            throw new IllegalArgumentException("illegal IPv4 address");
                        }
                        StringBuilder a = new StringBuilder();
                        new Formatter(a, Locale.US).format("%d.%d.%d.%d", new Object[] { Byte.valueOf(textToNumericFormatV4[0]), Byte.valueOf(textToNumericFormatV4[1]), Byte.valueOf(textToNumericFormatV4[2]), Byte.valueOf(textToNumericFormatV4[3]) });
                        s = a.toString();
                    }
                    else {
                        s = toLowerCase(s);
                    }
                }
            }
            this.hostname = s;
        }
        try {
            this.portrange = this.parsePort(str2);
        }
        catch (Exception ex) {
            throw new IllegalArgumentException("invalid port range: " + str2);
        }
    }
    
    static String toLowerCase(String s) {
        int length = s.length();
        Object o = null;
        for (int i = 0; i < length; ++i) {
            int char1 = s.charAt(i);
            if ((char1 >= 'a' && char1 <= 'z') || char1 == '.') {
                if (o != null) {
                    o.append((char)char1);
                }
            }
            else if ((char1 >= '0' && char1 <= '9') || char1 == '-') {
                if (o != null) {
                    o.append((char)char1);
                }
            }
            else if (char1 >= 'A' && char1 <= 'Z') {
                if (o == null) {
                    o = new StringBuilder(length);
                    o.append(s, 0, i);
                }
                o.append((char)(char1 + 32));
            }
            else {
                throw new IllegalArgumentException("Invalid characters in hostname");
            }
        }
        return (o == null) ? s : o.toString();
    }
    
    public boolean literal() {
        return this.literal;
    }
    
    public boolean ipv4Literal() {
        return this.ipv4;
    }
    
    public boolean ipv6Literal() {
        return this.ipv6;
    }
    
    public String hostname() {
        return this.hostname;
    }
    
    public int[] portrange() {
        return this.portrange;
    }
    
    public boolean wildcard() {
        return this.wildcard;
    }
    
    int[] defaultPort() {
        if (this.scheme.equals("http")) {
            return HostPortrange.HTTP_PORT;
        }
        if (this.scheme.equals("https")) {
            return HostPortrange.HTTPS_PORT;
        }
        return HostPortrange.NO_PORT;
    }
    
    int[] parsePort(String s) {
        if (s == null || s.equals("")) {
            return this.defaultPort();
        }
        if (s.equals("*")) {
            return new int[] { 0, 65535 };
        }
        try {
            int index = s.indexOf(45);
            if (index == -1) {
                int int3 = Integer.parseInt(s);
                return new int[] { int3, int3 };
            }
            String substring = s.substring(0, index);
            String substring2 = s.substring(index + 1);
            int int1;
            if (substring.equals("")) {
                int1 = 0;
            }
            else {
                int1 = Integer.parseInt(substring);
            }
            int int2;
            if (substring2.equals("")) {
                int2 = 65535;
            }
            else {
                int2 = Integer.parseInt(substring2);
            }
            if (int1 < 0 || int2 < 0 || int2 < int1) {
                return this.defaultPort();
            }
            return new int[] { int1, int2 };
        }
        catch (IllegalArgumentException ex) {
            return this.defaultPort();
        }
    }
    
    static {
        HTTP_PORT = new int[] { 80, 80 };
        HTTPS_PORT = new int[] { 443, 443 };
        NO_PORT = new int[] { -1, -1 };
    }
}
